# © 2020 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models, fields
from datetime import datetime


class DigiformaSession(models.Model):
    _name = 'digiforma.session.data'
    _description = "Sessions digiforma créées via devis Odoo"

    name = fields.Char('Nom')
    digiforma_id = fields.Integer('ID Digiforma')
    sale_order_id = fields.Many2one(
        comodel_name='sale.order',
        string='Sale_order_id',
        required=True)
    sale_order_line_id = fields.Many2one(
        comodel_name='sale.order.line',
        string='Sale_order_line_id',
        required=True)

    def get_sessions_to_display(self, *all_sessions_digiforma):
        res_sessions = list()
        for odoo_session in self:
            for remote_session in all_sessions_digiforma:
                remote_session_id = int(remote_session.get('id'))
                if odoo_session.digiforma_id == remote_session_id:
                    remote_session = self.get_data_to_display(**remote_session)
                    res_sessions.append(remote_session)
        return res_sessions

    def get_data_to_display(self, **session):
        dictionnary = {
            'draft': 'Projet',
            'incomplete': 'Plannification en cours',
            'ongoing': 'Plannifiée',
            'finished': 'Terminée',
        }
        for key, value in dictionnary.items():
            if session.get('pipelineState') == key:
                session['pipelineState'] = {
                    'key': key,
                    'value': value
                }
        if session.get('startDate'):
            session['startDate'] = \
                datetime.strptime(
                    session['startDate'], '%Y-%m-%d').strftime('%d/%m/%Y')
        if session.get('endDate'):
            session['endDate'] = \
                datetime.strptime(
                    session['endDate'], '%Y-%m-%d').strftime('%d/%m/%Y')
        if session.get('dates'):
            for date in session['dates']:
                date['date'] = datetime.strptime(
                    date['date'], '%Y-%m-%d').strftime('%d/%m/%Y')
                date['startTime'] = datetime.strptime(
                    date['startTime'], '%H:%M:%S').strftime('%Hh%M')
                date['endTime'] = datetime.strptime(
                    date['endTime'], '%H:%M:%S').strftime('%-Hh%M')

        return session
