# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models, fields, api
from odoo.exceptions import UserError


class CoSavoirsSaleOrderLine(models.Model):
    _name = 'sale.order.line'
    _inherit = ['sale.order.line', 'digiforma.api']

    digiforma_session_ids = fields.One2many(
        comodel_name='digiforma.session.data',
        inverse_name='sale_order_line_id',
        string='Sessions associées',
        required=False)

    count_digiforma_session = fields.Integer(
        'Sessions digiforma associées',
        compute='_compute_count_digiforma_session'
    )

    # ------------------------------------------------------
    # Compute fields
    # ------------------------------------------------------
    @api.multi
    def _compute_count_digiforma_session(self):
        for sol in self:
            sol.count_digiforma_session = len(sol.digiforma_session_ids)

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------
    def show_digiforma_sessions_sol(self):
        """
        Return sessions linked to sale order line
        :return: list of dict
        """
        sessions_to_show = list()
        all_sessions_digiforma = self.digiforma_get_all_sessions()

        if self.digiforma_session_ids:
            sessions_to_show.append(
                self.digiforma_session_ids.get_sessions_to_display(
                    *all_sessions_digiforma))

        return sessions_to_show

    def delete_digiforma_sessions_sol(self):
        """
        Delete digiforma sessions linked to sol
        :return:
        """
        sessions_digiforma_linked = self.digiforma_session_ids
        for session in sessions_digiforma_linked:
            if self.digiforma_delete_sessions(session.digiforma_id):
                session.unlink()
            else:
                raise UserError(
                    'La suppression des sessions n\'a pas fonctionné')

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------
    @api.multi
    def unlink(self):
        for sol in self:
            if sol.digiforma_session_ids:
                raise UserError(
                    'Vous ne pouvez pas supprimer une ligne de commandes'
                    ' rattachée à une ou des sessions Digiforma : \n Vous '
                    'pouvez supprimer les sessions associées.')
        return super(CoSavoirsSaleOrderLine, self).unlink()
